@@ -6,21 +6,22 @@ using Mooncake: rrule!!, CoDual, zero_fcodual, @is_primitive,
     @from_chainrules, @zero_adjoint, @mooncake_overlay, MinimalCtx,
     NoPullback
 
-@from_chainrules MinimalCtx Tuple{typeof(NonlinearSolveBase.solve_up),
+@from_chainrules MinimalCtx Tuple{
+    typeof(NonlinearSolveBase.solve_up),
     SciMLBase.AbstractNonlinearProblem,
-    Union{Nothing,SciMLBase.AbstractSensitivityAlgorithm},
+    Union{Nothing, SciMLBase.AbstractSensitivityAlgorithm},
+    Any,
     Any,
     Any,
-    Any
 } true
 
 # Dispatch for auto-alg
 @from_chainrules MinimalCtx Tuple{
     typeof(NonlinearSolveBase.solve_up),
     SciMLBase.AbstractNonlinearProblem,
-    Union{Nothing,SciMLBase.AbstractSensitivityAlgorithm},
+    Union{Nothing, SciMLBase.AbstractSensitivityAlgorithm},
+    Any,
     Any,
-    Any
 } true
 
 end
