@@ -28,23 +28,24 @@ function InternalAPI.init(
         abstol = nothing, reltol = nothing,
         timer = get_timer_output(),
         kwargs...
-)
+    )
     if Utils.unwrap_val(pre_inverted)
-        @assert length(fu)==length(u) "Non-Square Jacobian Inverse doesn't make sense."
+        @assert length(fu) == length(u) "Non-Square Jacobian Inverse doesn't make sense."
     end
     @bb δu = similar(u)
     δus = Utils.unwrap_val(shared) ≤ 1 ? nothing : map(2:Utils.unwrap_val(shared)) do i
-        @bb δu_ = similar(u)
+            @bb δu_ = similar(u)
     end
     if Utils.unwrap_val(pre_inverted)
 
         if haskey(kwargs, :verbose)
             linsolve_kwargs = merge(
-                (verbose = kwargs[:verbose].linear_verbosity,), linsolve_kwargs)
+                (verbose = kwargs[:verbose].linear_verbosity,), linsolve_kwargs
+            )
         end
-        
+
         lincache = construct_linear_solver(
-            alg, alg.linsolve, transpose(J), Utils.safe_vec(fu), Utils.safe_vec(u);
+            alg, alg.linsolve, transpose(J), Utils.safe_vec(fu), Utils.safe_vec(u), prob.p;
             stats, abstol, reltol, linsolve_kwargs...
         )
     else
@@ -56,7 +57,7 @@ end
 function InternalAPI.solve!(
         cache::SteepestDescentCache, J, fu, u, idx::Val = Val(1);
         new_jacobian::Bool = true, kwargs...
-)
+    )
     δu = SciMLBase.get_du(cache, idx)
     if Utils.unwrap_val(cache.preinverted_jacobian)
         A = J === nothing ? nothing : transpose(J)
@@ -70,7 +71,7 @@ function InternalAPI.solve!(
             return DescentResult(; δu, success = false, linsolve_success = false)
         end
     else
-        @assert J!==nothing "`J` must be provided when `preinverted_jacobian = Val(false)`."
+        @assert J !== nothing "`J` must be provided when `preinverted_jacobian = Val(false)`."
         @bb δu = transpose(J) × vec(fu)
     end
     @bb @. δu *= -1
