@@ -1,3 +1,8 @@
+@kwdef @concrete struct LinearSolveParameters
+    u
+    p
+end
+
 @kwdef @concrete struct LinearSolveResult
     u
     success::Bool = true
@@ -15,8 +20,10 @@ end
     stats::NLStats
 end
 
+SciMLBase.reinit!(::NativeJLLinearSolveCache; kwargs...) = nothing
+
 """
-    construct_linear_solver(alg, linsolve, A, b, u; stats, kwargs...)
+    construct_linear_solver(alg, linsolve, A, b, u, p; stats, kwargs...)
 
 Construct a cache for solving linear systems of the form `A * u = b`. Following cases are
 handled:
@@ -57,7 +64,7 @@ One distinct feature of this compared to the cache from LinearSolve is that it r
 aliasing arguments even after cache construction, i.e., if we passed in an `A` that `A` is
 not mutated, we do this by copying over `A` to a preconstructed cache.
 """
-function construct_linear_solver(alg, linsolve, A, b, u; stats, kwargs...)
+function construct_linear_solver(alg, linsolve, A, b, u, p; stats, kwargs...)
     if (A isa Number && b isa Number) || (A isa Diagonal)
         return NativeJLLinearSolveCache(A, b, stats)
     elseif linsolve isa typeof(\)
@@ -70,15 +77,17 @@ function construct_linear_solver(alg, linsolve, A, b, u; stats, kwargs...)
 
     u_fixed = fix_incompatible_linsolve_arguments(A, b, u)
     @bb u_cache = copy(u_fixed)
-    linprob = LinearProblem(A, b; u0 = u_cache)
+    linprob = LinearProblem(A, b, LinearSolveParameters(u_fixed, p); u0 = u_cache)
     # unlias here, we will later use these as caches
     lincache = init(
-        linprob, linsolve; alias = LinearAliasSpecifier(alias_A = false, alias_b = false), kwargs...)
+        linprob, linsolve; alias = LinearAliasSpecifier(alias_A = false, alias_b = false), kwargs...
+    )
     return LinearSolveJLCache(lincache, linsolve, stats)
 end
 
 function (cache::NativeJLLinearSolveCache)(;
-        A = nothing, b = nothing, linu = nothing, kwargs...)
+        A = nothing, b = nothing, linu = nothing, kwargs...
+    )
     cache.stats.nsolve += 1
     cache.stats.nfactors += 1
 
@@ -86,7 +95,7 @@ function (cache::NativeJLLinearSolveCache)(;
     b === nothing || (cache.b = b)
 
     if linu !== nothing && ArrayInterface.can_setindex(linu) &&
-       applicable(ldiv!, linu, cache.A, cache.b) && applicable(ldiv!, cache.A, linu)
+            applicable(ldiv!, linu, cache.A, cache.b) && applicable(ldiv!, cache.A, linu)
         ldiv!(linu, cache.A, cache.b)
         res = linu
     else
@@ -101,14 +110,14 @@ function fix_incompatible_linsolve_arguments(A, b, u::SArray)
     (Core.Compiler.return_type(\, Tuple{typeof(A), typeof(b)}) <: typeof(u)) && return u
     @warn lazy"Solving Linear System A::$(typeof(A)) x::$(typeof(u)) = b::$(typeof(u)) is not \
            properly supported. Converting `x` to a mutable array. Check the return type \
-           of the nonlinear function provided for optimal performance." maxlog=1
+           of the nonlinear function provided for optimal performance." maxlog = 1
     return MArray(u)
 end
 
 set_lincache_u!(cache, u) = setproperty!(cache.lincache, :u, u)
 function set_lincache_u!(cache, u::SArray)
     cache.lincache.u isa MArray && return set_lincache_u!(cache, MArray(u))
-    cache.lincache.u = u
+    return cache.lincache.u = u
 end
 
 function wrap_preconditioners(Pl, Pr, u)
