@@ -23,8 +23,10 @@ using InteractiveUtils, Test
 
         @test check_no_implicit_imports(NonlinearSolveBase; skip = (Base, Core)) === nothing
         # Ignore SciMLLogging types used by @verbosity_specifier macro (ExplicitImports can't track macro usage)
-        @test check_no_stale_explicit_imports(NonlinearSolveBase;
-            ignore = (:AbstractVerbositySpecifier, :All, :Detailed, :Minimal, :None, :Standard, :SciMLLogging)) === nothing
+        @test check_no_stale_explicit_imports(
+            NonlinearSolveBase;
+            ignore = (:AbstractMessageLevel, :AbstractVerbositySpecifier, :All, :Detailed, :Minimal, :None, :Standard, :SciMLLogging)
+        ) === nothing
         @test check_all_qualified_accesses_via_owners(NonlinearSolveBase) === nothing
     end
 
@@ -44,7 +46,7 @@ using InteractiveUtils, Test
             u_unaliased = nothing
             T = Float64
             cache = NonlinearSolveBase.NonlinearTerminationModeCache(
-                u_unaliased, SciMLBase.ReturnCode.Default, 1e-8, 1e-8, Inf, mode,
+                u_unaliased, SciMLBase.ReturnCode.Default, 1.0e-8, 1.0e-8, Inf, mode,
                 nothing, nothing, 0, nothing, nothing, nothing, nothing, nothing, false
             )
             du = [1.0, 1.0]
